==> ejc-sealm-impl-3.0.0-20220614.044040-95-sources.jar: com/ejianc/business/sealm/mapper/ZzyzMapper.java <==
package com.ejianc.business.sealm.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.sealm.bean.ZzyzEntity;
import com.ejianc.business.sealm.vo.ContractVO;
import com.ejianc.business.sealm.vo.ZzyzVO;
import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 组织印章
 * 
 * @author generator
 * 
 */
@Mapper
public interface ZzyzMapper extends BaseCrudMapper<ZzyzEntity> {
    List<ZzyzVO> queryStoreInstoreData(Page<ZzyzVO> page, @Param(Constants.WRAPPER) QueryWrapper wrapper);
    List<ContractVO> queryJxsbcgData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
    List<ContractVO> queryJxsbzlData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
    List<ContractVO> queryJxsbacData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);

    List<ContractVO> refSghtData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
    List<ContractVO> refClcgData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
    List<ContractVO> refFbData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);

    List<ContractVO> refQtzcData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);

    List<ContractVO> refZzcData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
}

==> ejc-sealm-impl-3.0.0-20220923.092521-122-sources.jar: com/ejianc/business/sealm/mapper/ZzyzMapper.java <==
package com.ejianc.business.sealm.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.sealm.bean.ZzyzEntity;
import com.ejianc.business.sealm.vo.ContractVO;
import com.ejianc.business.sealm.vo.ZzyzVO;
import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 组织印章
 * 
 * @author generator
 * 
 */
@Mapper
public interface ZzyzMapper extends BaseCrudMapper<ZzyzEntity> {
    List<ZzyzVO> queryStoreInstoreData(Page<ZzyzVO> page, @Param(Constants.WRAPPER) QueryWrapper wrapper);
    List<ContractVO> queryJxsbcgData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
    List<ContractVO> queryJxsbzlData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
    List<ContractVO> queryJxsbacData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);

    List<ContractVO> refSghtData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
    List<ContractVO> refClcgData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
    List<ContractVO> refFbData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);

    List<ContractVO> refQtzcData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
    List<ContractVO> refQtzc1Data(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
    List<ContractVO> refZzcData(Page<ContractVO> page, @Param(Constants.WRAPPER)QueryWrapper wrapper);
}
